@@ -257,7 +257,15 @@ impl<'src> Justfile<'src> {
 
     let mut ran = BTreeSet::new();
     for (recipe, arguments) in grouped {
-      Self::run_recipe(&context, recipe, arguments, &dotenv, search, &mut ran)?;
+      Self::run_recipe(
+        &context,
+        recipe,
+        arguments,
+        &dotenv,
+        search,
+        &self.settings,
+        &mut ran,
+      )?;
     }
 
     Ok(())
@@ -281,6 +289,7 @@ impl<'src> Justfile<'src> {
     arguments: &[&str],
     dotenv: &BTreeMap<String, String>,
     search: &Search,
+    settings: &Settings,
     ran: &mut BTreeSet<Vec<String>>,
   ) -> RunResult<'src, ()> {
     let mut invocation = vec![recipe.name().to_owned()];
@@ -319,6 +328,7 @@ impl<'src> Justfile<'src> {
         &arguments.iter().map(String::as_ref).collect::<Vec<&str>>(),
         dotenv,
         search,
+        settings,
         ran,
       )?;
     }
@@ -341,6 +351,7 @@ impl<'src> Justfile<'src> {
           &evaluated.iter().map(String::as_ref).collect::<Vec<&str>>(),
           dotenv,
           search,
+          settings,
           &mut ran,
         )?;
       }
