@@ -8,8 +8,10 @@ pub(crate) enum Keyword {
   DotenvLoad,
   Else,
   Export,
+  Fallback,
   False,
   If,
+  IgnoreComments,
   PositionalArguments,
   Set,
   Shell,
