@@ -95,7 +95,7 @@ impl<'src, D> Recipe<'src, D> {
     }
   }
 
-  pub(crate) fn run_linewise<'run>(
+  fn run_linewise<'run>(
     &self,
     context: &RecipeContext<'src, 'run>,
     dotenv: &BTreeMap<String, String>,
@@ -114,20 +114,31 @@ impl<'src, D> Recipe<'src, D> {
       let mut continued = false;
       let quiet_command = lines.peek().map_or(false, |line| line.is_quiet());
       let infallible_command = lines.peek().map_or(false, |line| line.is_infallible());
+
+      let comment_line =
+        context.settings.ignore_comments && lines.peek().map_or(false, |line| line.is_comment());
+
       loop {
         if lines.peek().is_none() {
           break;
         }
         let line = lines.next().unwrap();
         line_number += 1;
-        evaluated += &evaluator.evaluate_line(line, continued)?;
-        if line.is_continuation() {
+        if !comment_line {
+          evaluated += &evaluator.evaluate_line(line, continued)?;
+        }
+        if line.is_continuation() && !comment_line {
           continued = true;
           evaluated.pop();
         } else {
           break;
         }
       }
+
+      if comment_line {
+        continue;
+      }
+
       let mut command = evaluated.as_str();
 
       if quiet_command {
