@@ -5,6 +5,8 @@ pub(crate) enum Setting<'src> {
   AllowDuplicateRecipes(bool),
   DotenvLoad(bool),
   Export(bool),
+  Fallback(bool),
+  IgnoreComments(bool),
   PositionalArguments(bool),
   Shell(Shell<'src>),
   WindowsPowerShell(bool),
@@ -17,6 +19,8 @@ impl<'src> Display for Setting<'src> {
       Setting::AllowDuplicateRecipes(value)
       | Setting::DotenvLoad(value)
       | Setting::Export(value)
+      | Setting::Fallback(value)
+      | Setting::IgnoreComments(value)
       | Setting::PositionalArguments(value)
       | Setting::WindowsPowerShell(value) => write!(f, "{}", value),
       Setting::Shell(shell) | Setting::WindowsShell(shell) => write!(f, "{}", shell),
