@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 test! {
   name: long,
