@@ -42,8 +42,10 @@ fn alias() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
         "positional_arguments": false,
         "shell": null,
+        "ignore_comments": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -71,6 +73,8 @@ fn assignment() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -113,6 +117,8 @@ fn body() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -165,6 +171,8 @@ fn dependencies() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -254,6 +262,8 @@ fn dependency_argument() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -307,6 +317,8 @@ fn duplicate_recipes() {
         "allow_duplicate_recipes": true,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -342,6 +354,8 @@ fn doc_comment() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -365,6 +379,8 @@ fn empty_justfile() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -497,6 +513,8 @@ fn parameters() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -568,6 +586,8 @@ fn priors() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -603,6 +623,8 @@ fn private() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -638,6 +660,8 @@ fn quiet() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -664,7 +688,9 @@ fn settings() {
     "
       set dotenv-load
       set export
+      set fallback
       set positional-arguments
+      set ignore-comments
       set shell := ['a', 'b', 'c']
 
       foo:
@@ -691,6 +717,8 @@ fn settings() {
         "allow_duplicate_recipes": false,
         "dotenv_load": true,
         "export": true,
+        "fallback": true,
+        "ignore_comments": true,
         "positional_arguments": true,
         "shell": {
           "arguments": ["b", "c"],
@@ -732,6 +760,8 @@ fn shebang() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
@@ -767,8 +797,10 @@ fn simple() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
+        "fallback": false,
         "positional_arguments": false,
         "shell": null,
+        "ignore_comments": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
